from ....tl.tlobject import TLObject
from ....utils import get_input_peer
import os


class ForwardMessageRequest(TLObject):
    """Class generated by TLObjects' generator. All changes will be ERASED. TL definition below.
    messages.forwardMessage#33963bf9 peer:InputPeer id:int random_id:long = Updates"""

    # Telegram's constructor (U)ID for this class
    constructor_id = 0x33963bf9
    # Also the ID of its resulting type for fast checks
    subclass_of_id = 0x8af52aac

    def __init__(self, peer, id, random_id=None):
        """
        :param peer: Telegram type: "InputPeer".
        :param id: Telegram type: "int".
        :param random_id: Telegram type: "long".

        :returns Updates: Instance of either UpdatesTooLong, UpdateShortMessage, UpdateShortChatMessage, UpdateShort, UpdatesCombined, UpdatesTg, UpdateShortSentMessage.
        """
        super().__init__()
        self.result = None
        self.content_related = True

        self.peer = get_input_peer(peer)
        self.id = id
        self.random_id = random_id if random_id is not None else int.from_bytes(os.urandom(8), signed=True, byteorder='little')

    def to_dict(self):
        return {
            'peer': None if self.peer is None else self.peer.to_dict(),
            'id': self.id,
            'random_id': self.random_id,
        }

    def on_send(self, writer):
        writer.write_int(ForwardMessageRequest.constructor_id, signed=False)
        self.peer.on_send(writer)
        writer.write_int(self.id)
        writer.write_long(self.random_id)

    @staticmethod
    def empty():
        """Returns an "empty" instance (attributes=None)"""
        return ForwardMessageRequest(None, None, None)

    def on_response(self, reader):
        self.result = reader.tgread_object()

    def __repr__(self):
        return 'messages.forwardMessage#33963bf9 peer:InputPeer id:int random_id:long = Updates'

    def __str__(self):
        return TLObject.pretty_format(self)

    def stringify(self):
        return TLObject.pretty_format(self, indent=0)
